@@ -1,9 +1,6 @@
 /* SPDX-License-Identifier: GPL-2.0 WITH Linux-syscall-note */
 /* Protocol modification module for IP tables */
-
-#ifndef _XT_PROTO_H
-#define _XT_PROTO_H
-
+#pragma once
 #include <linux/types.h>
 
 enum {
@@ -13,8 +10,5 @@ enum {
 };
 
 struct xt_PROTO_info {
-	__u8	mode;
-	__u8	proto;
+	__u8 mode, proto;
 };
-
-#endif
