@@ -1,5 +1,4 @@
-#ifndef _LINUX_NETFILTER_XT_IFACE_H
-#define _LINUX_NETFILTER_XT_IFACE_H 1
+#pragma once
 
 enum {
 	XT_IFACE_UP          = 1 << 0,
@@ -19,8 +18,5 @@ enum {
 
 struct xt_iface_mtinfo {
 	char ifname[IFNAMSIZ];
-	__u16 flags;
-	__u16 invflags;
+	__u16 flags, invflags;
 };
-
-#endif
