@@ -6,9 +6,16 @@
 #include <linux/netfilter_ipv4/ip_tables.h>
 #include <net/tcp.h>
 #include <net/udp.h>
-#include <asm/unaligned.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6, 12, 0)
+#	include <linux/unaligned.h>
+#else
+#	include <asm/unaligned.h>
+#endif
 #include "xt_ipp2p.h"
 #include "compat_xtables.h"
+#if !defined(CONFIG_TEXTSEARCH_BM) && !defined(CONFIG_TEXTSEARCH_BM_MODULE)
+#	error CONFIG_TEXTSEARCH_BM=y/m is required for ipp2p. Either enable textsearch in your kernel ".config" file, or disable ipp2p in the "mconfig" file in Xtables-addons.
+#endif
 
 //#define IPP2P_DEBUG_ARES
 //#define IPP2P_DEBUG_SOUL
