@@ -1,5 +1,4 @@
-#ifndef _LINUX_NETFILTER_XT_IPV4OPTIONS_H
-#define _LINUX_NETFILTER_XT_IPV4OPTIONS_H 1
+#pragma once
 
 /* IPv4 allows for a 5-bit option number - 32 options */
 
@@ -18,9 +17,6 @@ enum xt_ipv4options_flags {
  * @flags:	see above
  */
 struct xt_ipv4options_mtinfo1 {
-	__u32 map;
-	__u32 invert;
+	__u32 map, invert;
 	__u8 flags;
 };
-
-#endif /* _LINUX_NETFILTER_XT_IPV4OPTIONS_H */
